package com.hw.mes.mapper;

import java.util.List;
import com.hw.mes.domain.MesProductOrder;

/**
 * 生产工单Mapper接口
 * 
 * @author Yinq
 * @date 2024-02-20
 */
public interface MesProductOrderMapper 
{
    /**
     * 查询生产工单
     * 
     * @param productOrderId 生产工单主键
     * @return 生产工单
     */
    public MesProductOrder selectMesProductOrderByProductOrderId(Long productOrderId);

    /**
     * 查询生产工单列表
     * 
     * @param mesProductOrder 生产工单
     * @return 生产工单集合
     */
    public List<MesProductOrder> selectMesProductOrderList(MesProductOrder mesProductOrder);

    /**
     * 新增生产工单
     * 
     * @param mesProductOrder 生产工单
     * @return 结果
     */
    public int insertMesProductOrder(MesProductOrder mesProductOrder);

    /**
     * 修改生产工单
     * 
     * @param mesProductOrder 生产工单
     * @return 结果
     */
    public int updateMesProductOrder(MesProductOrder mesProductOrder);

    /**
     * 删除生产工单
     * 
     * @param productOrderId 生产工单主键
     * @return 结果
     */
    public int deleteMesProductOrderByProductOrderId(Long productOrderId);

    /**
     * 批量删除生产工单
     * 
     * @param productOrderIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMesProductOrderByProductOrderIds(Long[] productOrderIds);
}
